@@ -16,6 +16,21 @@ pub struct Config {
     pub bump: u8,
 }
 
+impl std::fmt::Display for Config {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(
+            f,
+            "{{
+    admin: {},
+    min_recurr: {},
+    program_fee: {},
+    worker_fee: {}
+}}",
+            self.admin, self.min_recurr, self.program_fee, self.worker_fee
+        )
+    }
+}
+
 impl TryFrom<Vec<u8>> for Config {
     type Error = ProgramError;
     fn try_from(data: Vec<u8>) -> Result<Self, Self::Error> {
